@@ -5,7 +5,7 @@ A library and command line tool to notify you of relevant
 questions as soon as they're posted on Stack Overflow.
 """
 __author__ = 'Matt Deacalion Stevens'
-__version__ = '0.3.0'
+__version__ = '0.3.1'
 
 import re
 import time
@@ -97,7 +97,18 @@ class Question(object):
         """
         Overriden to display a short URL and short title.
         """
-        return '{} {}'.format(self.get_short_link(), self.get_short_title(70))
+        s = self.__unicode__()
+
+        if isinstance(s, str):
+            return s
+        else:
+            return s.encode('utf-8')
+
+    def __unicode__(self):
+        """
+        Overriden to display a short URL and short title.
+        """
+        return u'{} {}'.format(self.get_short_link(), self.get_short_title(70))
 
     def __getitem__(self, attribute):
         """
@@ -275,7 +286,7 @@ class Retriever(object):
         Takes a HTTP requests response object, extracts the questions from it
         and returns a list of question dicts.
         """
-        return json.loads(response.content.decode())['items']
+        return json.loads(response.content.decode('utf-8'))['items']
 
     def _get_questions_from_feed(self):
         """
